<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <div class="search-container">
            <el-form ref="form" :model="searchForm" label-width="auto" style="width: 100%">
                <el-row :gutter="20">
                    <el-col :span="5">
                        <el-form-item label="项目名称">
                            <el-input v-model="queryParam.querys[0].value" clearable placeholder="请输入项目名称">
                            </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="项目分类">
                            <dict-select dictCode="sgyp-xmfl" :hasDefaultOption="true" clearable
                                v-model="queryParam.querys[8].value" style="width: 100%" placeholder="请选择项目分类" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="专项小组">
                            <dict-select dictCode="zxxz" v-model="queryParam.querys[1].value" :hasDefaultOption="true"
                                clearable style="width: 100%" placeholder="请选择专项小组" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="发布年度">
                            <el-date-picker v-model="queryParam.querys[3].value" placeholder="请选择发布年度" format="yyyy"
                                value-format="yyyy" type="year" style="width: 100%">
                            </el-date-picker>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch(1)">
                            搜索
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div ref="btnPanel">
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{ width: '100%' }">
                        <el-table-column label="序号" type="index" width="60" align="center"></el-table-column>
                        <el-table-column prop="projectName" min-width="220" show-overflow-tooltip label="项目名称" align="center">
                        </el-table-column>
                        <!-- <el-table-column prop="projectName" show-overflow-tooltip label="项目类型" align="center">
                            <template v-slot="{ row }">
                                {{ getDictName('xmlx', row.projectType) }}
                            </template>
                        </el-table-column> -->
                        <el-table-column prop="groupName" min-width="120" show-overflow-tooltip label="专项小组" align="center">
                        </el-table-column>
                        <el-table-column prop="unitName" min-width="100" show-overflow-tooltip label="主责单位" align="center">
                        </el-table-column>
                        <el-table-column prop="createTime" min-width="120" show-overflow-tooltip label="填报时间" align="center">
                        </el-table-column>
                        <el-table-column prop="pstatus" width="130" show-overflow-tooltip label="审核状态" align="center">
                            <template v-slot="{ row }">
                                <el-tag :type="row.pstatus === 1 ? '' : row.pstatus === 2 ? 'danger' : row.pstatus === 3 ? 'success' : 'info'">
                                    {{ getDictName('lgyp_shzt', row.pstatus) || '待更新' }}
                                </el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column show-overflow-tooltip align="center" fixed="right" width="180" label="操作">
                            <template v-slot="{ row }">
                                <el-link v-if="!row.pstatus && row.pstatus !== 0" icon="el-icon-refresh" type="danger"
                                    :underline="false" class="del-btn" @click="advanceRenewal('更新', row)">
                                    待更新
                                </el-link>
                                <template v-else>
                                    <el-link v-if="row.pstatus > 1" icon="el-icon-refresh" type="primary"
                                        @click="advanceRenewal('更新', row)" :underline="false" class="cloumn-btn">
                                        更新
                                    </el-link>
                                    <el-link v-if="row.pstatus === 0" icon="el-icon-s-check" type="primary"
                                        @click="advanceReport(row, 1)" :underline="false" class="cloumn-btn">
                                        上报
                                    </el-link>
                                    <el-link v-if="row.pstatus === 0" icon="el-icon-edit" type="primary"
                                        @click="advanceRenewal('编辑', row)" :underline="false" class="cloumn-btn">
                                        编辑
                                    </el-link>
                                    <el-link v-if="row.pstatus === 1" icon="el-icon-view" type="primary"
                                        :underline="false" class="cloumn-btn" @click="advanceRenewal('详情', row)">
                                        详情
                                    </el-link>
                                    <el-link v-if="row.pstatus === 1" icon="el-icon-refresh-left" type="danger"
                                        @click="advanceReport(row, 0)" :underline="false" class="del-btn">
                                        撤回
                                    </el-link>
                                </template>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="queryParam.pageBean"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
        <ProjectDialog ref="majorProjectsDialog" @getData="getData"></ProjectDialog>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import utils from '@/utils.js'
import apiList from '@/api/MajorProject'
import ProjectDialog from '../ProjectDialog.vue'
export default {
    name: 'StartCreateEntry',
    components: {
        pagination,
        ProjectDialog
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            searchForm: {},
            loading: false,
            tableData: [],
            multipleSelection: [],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'project_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'group_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'm.unit_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'year(m.create_time_)',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'project_Field_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'project_Runway_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'project_Type_',
                        relation: 'AND',
                        value: 3,
                    },
                    {
                        group: 'main',
                        operation: 'IN',
                        parentGroup: '',
                        property: 'p.status_',
                        relation: 'AND',
                        value: [],
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        property: 'project_Category_',
                        relation: 'AND',
                        value: ''
                    },
                ]
            },
        }
    },
    created() {
        this.getData()
    },
    mounted() { },
    methods: {
        // 推进更新
        advanceRenewal(title, data) {
            this.$refs.majorProjectsDialog.openDialog(title, data)
        },
        advanceReport(row, status) {
            let msg = status ? '上报' : '撤回'
            this.$confirm(`确认${msg}吗？`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(() => {
                this.markLoading = true
                let { pid,id } = row
                let data = {
                    id: pid,
                    status,
                    projectId: id,
                    approvalResults: status ? '' : '2'
                }
                apiList.updateStatusById(data,res => {
                    if (res.state) {
                        this.$message.success(`${msg}成功`)
                        row.pstatus = status
                    }
                    this.markLoading = false
                })
            })
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        handleSearch(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.getData()
        },
        //获取数据
        getData() {
            this.loading = true
            this.tableData = []
            apiList.getAdvanceData(this.queryParam, false, (res) => {
                if (res.rows) {
                    this.tableData = res.rows
                    this.queryParam.pageBean.page = res.page
                    this.queryParam.pageBean.total = res.total
                    // this.$set(this.tableData)
                    this.loading = false
                }
            })
        },
        //展示数量
        handleSizeChange(val) {
            this.queryParam.pageBean.pageSize = val
            this.handleSearch(1)
        },
        //表格页数
        handleCurrentChange(val) {
            this.queryParam.pageBean.page = val
            this.handleSearch(val)
        },
    },
}
</script>

<style lang="scss" scoped>
.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.del-btn {
    border: 1px solid #f56c6c;
    padding: 3px 10px;
    border-radius: 5px;
    margin-right: 5px;

    &:hover {
        background-color: #f56c6c;
        color: #fff;
    }
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;
    margin-right: 5px;

    &:hover {
        background-color: #2761ff;
        color: #fff;
    }

    /deep/ i,
    span {
        font-size: 16px;
    }
}
</style>
